OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Data d'enviament del darrer informe: {on}",
    "An error occurred while sending your report." : "S'ha produït un error en enviar l'informe.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Llista d'aplicacions <em>(per a cada aplicació: nom, versió, estat d'habilitació)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Entorn de la base de dades <em>(tipus, versió, mida de la base de dades)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informació del xifratge <em>(estat d'habilitació, mòdul per defecte)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Nombre d'elements compartits <em>(per tipus i paràmetre de permisos)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Entorn de PHP <em>(versió, límit de memòria, temps d'execució màxim, mida de fitxer màxima)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Detalls de la instància del servidor <em>(versió, memòria cau en ús, estat de blocatge/previsualitzacions/avatars)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Estadístiques <em>(nombre de fitxers, usuaris, emmagatzematges per tipus, comentaris i etiquetes)</em>",
    "Usage survey" : "Enquesta d'ús",
    "Help improve Nextcloud" : "Ajudeu a millorar el Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Voleu ajudar-nos a millorar el Nextcloud proporcionant dades anònimes sobre la vostra configuració i ús? Podeu inhabilitar-ho en qualsevol moment en la configuració de l'administrador.",
    "Not now" : "Ara no",
    "Send usage" : "Envia l'ús",
    "Never" : "Mai",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envia dades anònimes al Nextcloud per a ajudar-nos a millorar el Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Envia dades anònimes al Nextcloud per a ajudar-nos a millorar el Nextcloud.\n\t\tSempre teniu el control total sobre el contingut enviat al Nextcloud i ho podeu inhabilitar\n\t\ten qualsevol moment.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Podeu ajudar a millorar el Nextcloud enviant-nos algunes dades sobre la vostra configuració i ús actuals.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Ens prenem seriosament la vostra privadesa. L'enviament de dades està inhabilitat per defecte i, si el voleu habilitar, serà anònim i tindreu l'opció de triar què voleu compartir. En rebre un informe, se suprimeix l'anterior. Pugeu un informe net per a suprimir totes les dades emmagatzemades actualment en el servidor.",
    "Send new report now" : "Envia un informe nou ara ",
    "Send usage survey monthly" : "Envia una enquesta d'ús mensualment",
    "Data to send" : "Dades que s'enviaran",
    "Last report sent on: %s" : "Data d'enviament del darrer informe: %s",
    "Last report" : "Darrer informe",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Envia dades anònimes al Nextcloud per a ajudar-nos a millorar el Nextcloud.\nSempre teniu el control total sobre el contingut enviat al Nextcloud i ho podeu inhabilitar\nen qualsevol moment."
},
"nplurals=2; plural=(n != 1);");
